# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': '.'}

packages = \
['src']

package_data = \
{'': ['*']}

install_requires = \
['SQLAlchemy>=1.4.25,<2.0.0', 'requests>=2.26.0,<3.0.0']

entry_points = \
{'console_scripts': ['garden-gateway = src.main:main']}

setup_kwargs = {
    'name': 'garden-gateway',
    'version': '0.0.2',
    'description': 'Gateway that integrates the sensors for the garden and the mushrooms',
    'long_description': None,
    'author': 'Jeff Labonte',
    'author_email': 'grimsleepless@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
